@@ -299,6 +299,9 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # The TKE cluster ID is invalid, or the TKE cluster is not eligible.
 INVALIDPARAMETERVALUE_INVALIDTKEINSTANCE = 'InvalidParameterValue.InvalidTkeInstance'
 
+# The number of security groups exceeds the limit.
+LIMITEXCEEDED_SECURITYGROUPNUMLIMITEXCEEDED = 'LimitExceeded.SecurityGroupNumLimitExceeded'
+
 # Missing parameter.
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -344,6 +347,9 @@ RESOURCESSOLDOUT_CBSSOLDOUT = 'ResourcesSoldOut.CbsSoldOut'
 # CVM instances have been sold out.
 RESOURCESSOLDOUT_CVMSOLDOUT = 'ResourcesSoldOut.CvmSoldOut'
 
+# Unauthorized operation.
+UNAUTHORIZEDOPERATION_CHECKCAMAUTH = 'UnauthorizedOperation.CheckCamAuth'
+
 # Unknown parameter.
 UNKNOWNPARAMETER = 'UnknownParameter'
 
