@@ -1453,7 +1453,7 @@ class TkeClient(AbstractClient):
 
 
     def DescribeEdgeLogSwitches(self, request):
-        """This API is used to query the status of events, audits and logs.
+        """This API is used to query the status of event storage, cluster auditing and logging.
 
         :param request: Request instance for DescribeEdgeLogSwitches.
         :type request: :class:`tencentcloud.tke.v20180525.models.DescribeEdgeLogSwitchesRequest`
